==> chaosmesh-model-5.1.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/AttrOverrideSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface AttrOverrideSpecFluent<A extends AttrOverrideSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAtime instead.
 * @return The buildable object.
 */
@Deprecated public Timespec getAtime();
    public Timespec buildAtime();
    public A withAtime(Timespec atime);
    public Boolean hasAtime();
    public A withNewAtime(Long nsec,Long sec);
    public AttrOverrideSpecFluent.AtimeNested<A> withNewAtime();
    public AttrOverrideSpecFluent.AtimeNested<A> withNewAtimeLike(Timespec item);
    public AttrOverrideSpecFluent.AtimeNested<A> editAtime();
    public AttrOverrideSpecFluent.AtimeNested<A> editOrNewAtime();
    public AttrOverrideSpecFluent.AtimeNested<A> editOrNewAtimeLike(Timespec item);
    public Long getBlocks();
    public A withBlocks(Long blocks);
    public Boolean hasBlocks();
    public A withNewBlocks(String arg1);
    public A withNewBlocks(long arg1);
    
/**
 * This method has been deprecated, please use method buildCtime instead.
 * @return The buildable object.
 */
@Deprecated public Timespec getCtime();
    public Timespec buildCtime();
    public A withCtime(Timespec ctime);
    public Boolean hasCtime();
    public A withNewCtime(Long nsec,Long sec);
    public AttrOverrideSpecFluent.CtimeNested<A> withNewCtime();
    public AttrOverrideSpecFluent.CtimeNested<A> withNewCtimeLike(Timespec item);
    public AttrOverrideSpecFluent.CtimeNested<A> editCtime();
    public AttrOverrideSpecFluent.CtimeNested<A> editOrNewCtime();
    public AttrOverrideSpecFluent.CtimeNested<A> editOrNewCtimeLike(Timespec item);
    public Long getGid();
    public A withGid(Long gid);
    public Boolean hasGid();
    public A withNewGid(String arg1);
    public A withNewGid(long arg1);
    public Long getIno();
    public A withIno(Long ino);
    public Boolean hasIno();
    public A withNewIno(String arg1);
    public A withNewIno(long arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMtime instead.
 * @return The buildable object.
 */
@Deprecated public Timespec getMtime();
    public Timespec buildMtime();
    public A withMtime(Timespec mtime);
    public Boolean hasMtime();
    public A withNewMtime(Long nsec,Long sec);
    public AttrOverrideSpecFluent.MtimeNested<A> withNewMtime();
    public AttrOverrideSpecFluent.MtimeNested<A> withNewMtimeLike(Timespec item);
    public AttrOverrideSpecFluent.MtimeNested<A> editMtime();
    public AttrOverrideSpecFluent.MtimeNested<A> editOrNewMtime();
    public AttrOverrideSpecFluent.MtimeNested<A> editOrNewMtimeLike(Timespec item);
    public Long getNlink();
    public A withNlink(Long nlink);
    public Boolean hasNlink();
    public A withNewNlink(String arg1);
    public A withNewNlink(long arg1);
    public Integer getPerm();
    public A withPerm(Integer perm);
    public Boolean hasPerm();
    public A withNewPerm(String arg1);
    public A withNewPerm(int arg1);
    public Long getRdev();
    public A withRdev(Long rdev);
    public Boolean hasRdev();
    public A withNewRdev(String arg1);
    public A withNewRdev(long arg1);
    public Long getSize();
    public A withSize(Long size);
    public Boolean hasSize();
    public A withNewSize(String arg1);
    public A withNewSize(long arg1);
    public Long getUid();
    public A withUid(Long uid);
    public Boolean hasUid();
    public A withNewUid(String arg1);
    public A withNewUid(long arg1);
    public interface AtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TimespecFluent<AttrOverrideSpecFluent.AtimeNested<N>> {

            public N and();
            public N endAtime();    }


    public interface CtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TimespecFluent<AttrOverrideSpecFluent.CtimeNested<N>> {

            public N and();
            public N endCtime();    }


    public interface MtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TimespecFluent<AttrOverrideSpecFluent.MtimeNested<N>> {

            public N and();
            public N endMtime();    }


}

==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/AttrOverrideSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface AttrOverrideSpecFluent<A extends AttrOverrideSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAtime instead.
 * @return The buildable object.
 */
@Deprecated public Timespec getAtime();
    public Timespec buildAtime();
    public A withAtime(Timespec atime);
    public Boolean hasAtime();
    public A withNewAtime(Long nsec,Long sec);
    public AttrOverrideSpecFluent.AtimeNested<A> withNewAtime();
    public AttrOverrideSpecFluent.AtimeNested<A> withNewAtimeLike(Timespec item);
    public AttrOverrideSpecFluent.AtimeNested<A> editAtime();
    public AttrOverrideSpecFluent.AtimeNested<A> editOrNewAtime();
    public AttrOverrideSpecFluent.AtimeNested<A> editOrNewAtimeLike(Timespec item);
    public Long getBlocks();
    public A withBlocks(Long blocks);
    public Boolean hasBlocks();
    public A withNewBlocks(long arg1);
    
/**
 * This method has been deprecated, please use method buildCtime instead.
 * @return The buildable object.
 */
@Deprecated public Timespec getCtime();
    public Timespec buildCtime();
    public A withCtime(Timespec ctime);
    public Boolean hasCtime();
    public A withNewCtime(Long nsec,Long sec);
    public AttrOverrideSpecFluent.CtimeNested<A> withNewCtime();
    public AttrOverrideSpecFluent.CtimeNested<A> withNewCtimeLike(Timespec item);
    public AttrOverrideSpecFluent.CtimeNested<A> editCtime();
    public AttrOverrideSpecFluent.CtimeNested<A> editOrNewCtime();
    public AttrOverrideSpecFluent.CtimeNested<A> editOrNewCtimeLike(Timespec item);
    public Long getGid();
    public A withGid(Long gid);
    public Boolean hasGid();
    public A withNewGid(long arg1);
    public Long getIno();
    public A withIno(Long ino);
    public Boolean hasIno();
    public A withNewIno(long arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMtime instead.
 * @return The buildable object.
 */
@Deprecated public Timespec getMtime();
    public Timespec buildMtime();
    public A withMtime(Timespec mtime);
    public Boolean hasMtime();
    public A withNewMtime(Long nsec,Long sec);
    public AttrOverrideSpecFluent.MtimeNested<A> withNewMtime();
    public AttrOverrideSpecFluent.MtimeNested<A> withNewMtimeLike(Timespec item);
    public AttrOverrideSpecFluent.MtimeNested<A> editMtime();
    public AttrOverrideSpecFluent.MtimeNested<A> editOrNewMtime();
    public AttrOverrideSpecFluent.MtimeNested<A> editOrNewMtimeLike(Timespec item);
    public Long getNlink();
    public A withNlink(Long nlink);
    public Boolean hasNlink();
    public A withNewNlink(long arg1);
    public Integer getPerm();
    public A withPerm(Integer perm);
    public Boolean hasPerm();
    public A withNewPerm(int arg1);
    public Long getRdev();
    public A withRdev(Long rdev);
    public Boolean hasRdev();
    public A withNewRdev(long arg1);
    public Long getSize();
    public A withSize(Long size);
    public Boolean hasSize();
    public A withNewSize(long arg1);
    public Long getUid();
    public A withUid(Long uid);
    public Boolean hasUid();
    public A withNewUid(long arg1);
    public interface AtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TimespecFluent<AttrOverrideSpecFluent.AtimeNested<N>> {

            public N and();
            public N endAtime();    }


    public interface CtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TimespecFluent<AttrOverrideSpecFluent.CtimeNested<N>> {

            public N and();
            public N endCtime();    }


    public interface MtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TimespecFluent<AttrOverrideSpecFluent.MtimeNested<N>> {

            public N and();
            public N endMtime();    }


}
